@@ -1,4 +1,4 @@
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext as _
 
 from allianceauth import hooks
 from allianceauth.services.hooks import MenuItemHook, UrlHook
